test_abc_function <- function(param) {
  return(min(param, na.rm = TRUE))
}
